@@ -78,6 +78,10 @@ class TestV4Local:
             pytest.fail("Key.from_paserk should fail.")
         assert msg in str(err.value)
 
+    def test_v4_local_to_peer_paserk_id(self):
+        k = Key.new(4, "local", b"our-secret")
+        assert k.to_peer_paserk_id() == ""
+
 
 class TestV4Public:
     """
